@@ -1,10 +1,17 @@
+import warnings
+
+warnings.warn(
+    "mkdocs.commands.setup is never used in MkDocs and will be removed soon.", DeprecationWarning
+)
+
 try:
     from mkdocs.commands.babel import (
         compile_catalog,
         extract_messages,
         init_catalog,
-        update_catalog
+        update_catalog,
     )
+
     babel_cmdclass = {
         'compile_catalog': compile_catalog,
         'extract_messages': extract_messages,
