@@ -1,21 +1,21 @@
 #!/usr/bin/env python
 
-from unittest import mock
 import unittest
+from unittest import mock
 
+from mkdocs.commands import build
 from mkdocs.exceptions import PluginError
-from mkdocs.structure.pages import Page
 from mkdocs.structure.files import File, Files
 from mkdocs.structure.nav import get_navigation
-from mkdocs.commands import build
-from mkdocs.tests.base import load_config, tempdir, PathAssertionMixin
+from mkdocs.structure.pages import Page
+from mkdocs.tests.base import PathAssertionMixin, load_config, tempdir
 from mkdocs.utils import meta
 
 
 def build_page(title, path, config, md_src=''):
-    """ Helper which returns a Page object. """
+    """Helper which returns a Page object."""
 
-    files = Files([File(path, config['docs_dir'], config['site_dir'], config['use_directory_urls'])])
+    files = Files([File(path, config.docs_dir, config.site_dir, config.use_directory_urls)])
     page = Page(title, list(files)[0], config)
     # Fake page.read_source()
     page.markdown, page.meta = meta.get_data(md_src)
@@ -23,9 +23,8 @@ def build_page(title, path, config, md_src=''):
 
 
 class BuildTests(PathAssertionMixin, unittest.TestCase):
-
     def _get_env_with_null_translations(self, config):
-        env = config['theme'].get_env()
+        env = config.theme.get_env()
         env.add_extension('jinja2.ext.i18n')
         env.install_null_translations()
         return env
@@ -34,24 +33,26 @@ class BuildTests(PathAssertionMixin, unittest.TestCase):
 
     def test_context_base_url_homepage(self):
         nav_cfg = [
-            {'Home': 'index.md'}
+            {'Home': 'index.md'},
         ]
         cfg = load_config(nav=nav_cfg, use_directory_urls=False)
-        files = Files([
+        fs = [
             File('index.md', cfg['docs_dir'], cfg['site_dir'], cfg['use_directory_urls']),
-        ])
+        ]
+        files = Files(fs)
         nav = get_navigation(files, cfg)
         context = build.get_context(nav, files, cfg, nav.pages[0])
         self.assertEqual(context['base_url'], '.')
 
     def test_context_base_url_homepage_use_directory_urls(self):
         nav_cfg = [
-            {'Home': 'index.md'}
+            {'Home': 'index.md'},
         ]
         cfg = load_config(nav=nav_cfg)
-        files = Files([
+        fs = [
             File('index.md', cfg['docs_dir'], cfg['site_dir'], cfg['use_directory_urls']),
-        ])
+        ]
+        files = Files(fs)
         nav = get_navigation(files, cfg)
         context = build.get_context(nav, files, cfg, nav.pages[0])
         self.assertEqual(context['base_url'], '.')
@@ -59,13 +60,14 @@ class BuildTests(PathAssertionMixin, unittest.TestCase):
     def test_context_base_url_nested_page(self):
         nav_cfg = [
             {'Home': 'index.md'},
-            {'Nested': 'foo/bar.md'}
+            {'Nested': 'foo/bar.md'},
         ]
         cfg = load_config(nav=nav_cfg, use_directory_urls=False)
-        files = Files([
+        fs = [
             File('index.md', cfg['docs_dir'], cfg['site_dir'], cfg['use_directory_urls']),
-            File('foo/bar.md', cfg['docs_dir'], cfg['site_dir'], cfg['use_directory_urls'])
-        ])
+            File('foo/bar.md', cfg['docs_dir'], cfg['site_dir'], cfg['use_directory_urls']),
+        ]
+        files = Files(fs)
         nav = get_navigation(files, cfg)
         context = build.get_context(nav, files, cfg, nav.pages[1])
         self.assertEqual(context['base_url'], '..')
@@ -73,13 +75,14 @@ class BuildTests(PathAssertionMixin, unittest.TestCase):
     def test_context_base_url_nested_page_use_directory_urls(self):
         nav_cfg = [
             {'Home': 'index.md'},
-            {'Nested': 'foo/bar.md'}
+            {'Nested': 'foo/bar.md'},
         ]
         cfg = load_config(nav=nav_cfg)
-        files = Files([
+        fs = [
             File('index.md', cfg['docs_dir'], cfg['site_dir'], cfg['use_directory_urls']),
-            File('foo/bar.md', cfg['docs_dir'], cfg['site_dir'], cfg['use_directory_urls'])
-        ])
+            File('foo/bar.md', cfg['docs_dir'], cfg['site_dir'], cfg['use_directory_urls']),
+        ]
+        files = Files(fs)
         nav = get_navigation(files, cfg)
         context = build.get_context(nav, files, cfg, nav.pages[1])
         self.assertEqual(context['base_url'], '../..')
@@ -116,17 +119,18 @@ class BuildTests(PathAssertionMixin, unittest.TestCase):
 
     def test_context_extra_css_js_from_homepage(self):
         nav_cfg = [
-            {'Home': 'index.md'}
+            {'Home': 'index.md'},
         ]
         cfg = load_config(
             nav=nav_cfg,
             extra_css=['style.css'],
             extra_javascript=['script.js'],
-            use_directory_urls=False
+            use_directory_urls=False,
         )
-        files = Files([
+        fs = [
             File('index.md', cfg['docs_dir'], cfg['site_dir'], cfg['use_directory_urls']),
-        ])
+        ]
+        files = Files(fs)
         nav = get_navigation(files, cfg)
         context = build.get_context(nav, files, cfg, nav.pages[0])
         self.assertEqual(context['extra_css'], ['style.css'])
@@ -135,18 +139,19 @@ class BuildTests(PathAssertionMixin, unittest.TestCase):
     def test_context_extra_css_js_from_nested_page(self):
         nav_cfg = [
             {'Home': 'index.md'},
-            {'Nested': 'foo/bar.md'}
+            {'Nested': 'foo/bar.md'},
         ]
         cfg = load_config(
             nav=nav_cfg,
             extra_css=['style.css'],
             extra_javascript=['script.js'],
-            use_directory_urls=False
+            use_directory_urls=False,
         )
-        files = Files([
+        fs = [
             File('index.md', cfg['docs_dir'], cfg['site_dir'], cfg['use_directory_urls']),
-            File('foo/bar.md', cfg['docs_dir'], cfg['site_dir'], cfg['use_directory_urls'])
-        ])
+            File('foo/bar.md', cfg['docs_dir'], cfg['site_dir'], cfg['use_directory_urls']),
+        ]
+        files = Files(fs)
         nav = get_navigation(files, cfg)
         context = build.get_context(nav, files, cfg, nav.pages[1])
         self.assertEqual(context['extra_css'], ['../style.css'])
@@ -155,22 +160,48 @@ class BuildTests(PathAssertionMixin, unittest.TestCase):
     def test_context_extra_css_js_from_nested_page_use_directory_urls(self):
         nav_cfg = [
             {'Home': 'index.md'},
-            {'Nested': 'foo/bar.md'}
+            {'Nested': 'foo/bar.md'},
         ]
         cfg = load_config(
             nav=nav_cfg,
             extra_css=['style.css'],
-            extra_javascript=['script.js']
+            extra_javascript=['script.js'],
         )
-        files = Files([
+        fs = [
             File('index.md', cfg['docs_dir'], cfg['site_dir'], cfg['use_directory_urls']),
-            File('foo/bar.md', cfg['docs_dir'], cfg['site_dir'], cfg['use_directory_urls'])
-        ])
+            File('foo/bar.md', cfg['docs_dir'], cfg['site_dir'], cfg['use_directory_urls']),
+        ]
+        files = Files(fs)
         nav = get_navigation(files, cfg)
         context = build.get_context(nav, files, cfg, nav.pages[1])
         self.assertEqual(context['extra_css'], ['../../style.css'])
         self.assertEqual(context['extra_javascript'], ['../../script.js'])
 
+    # TODO: This shouldn't pass on Linux
+    # @unittest.skipUnless(sys.platform.startswith("win"), "requires Windows")
+    def test_context_extra_css_path_warning(self):
+        nav_cfg = [
+            {'Home': 'index.md'},
+        ]
+        cfg = load_config(
+            nav=nav_cfg,
+            extra_css=['assets\\style.css'],
+            use_directory_urls=False,
+        )
+        fs = [
+            File('index.md', cfg['docs_dir'], cfg['site_dir'], cfg['use_directory_urls']),
+        ]
+        files = Files(fs)
+        nav = get_navigation(files, cfg)
+        with self.assertLogs('mkdocs') as cm:
+            context = build.get_context(nav, files, cfg, nav.pages[0])
+        self.assertEqual(context['extra_css'], ['assets/style.css'])
+        self.assertEqual(
+            '\n'.join(cm.output),
+            "WARNING:mkdocs.utils:Path 'assets\\style.css' uses OS-specific separator '\\'. "
+            "That will be unsupported in a future release. Please change it to '/'.",
+        )
+
     def test_context_extra_css_js_no_page(self):
         cfg = load_config(extra_css=['style.css'], extra_javascript=['script.js'])
         context = build.get_context(mock.Mock(), mock.Mock(), cfg, base_url='..')
@@ -196,8 +227,11 @@ class BuildTests(PathAssertionMixin, unittest.TestCase):
     @mock.patch('mkdocs.utils.write_file')
     @mock.patch('mkdocs.commands.build._build_template', return_value='some content')
     @mock.patch('gzip.GzipFile')
-    def test_build_sitemap_template(self, mock_gzip_gzipfile, mock_build_template, mock_write_file):
-        cfg = load_config()
+    @tempdir()
+    def test_build_sitemap_template(
+        self, site_dir, mock_gzip_gzipfile, mock_build_template, mock_write_file
+    ):
+        cfg = load_config(site_dir=site_dir)
         env = cfg['theme'].get_env()
         build._build_theme_template('sitemap.xml', env, mock.Mock(), cfg, mock.Mock())
         mock_write_file.assert_called_once()
@@ -209,11 +243,11 @@ class BuildTests(PathAssertionMixin, unittest.TestCase):
     def test_skip_missing_theme_template(self, mock_build_template, mock_write_file):
         cfg = load_config()
         env = cfg['theme'].get_env()
-        with self.assertLogs('mkdocs', level='WARN') as cm:
+        with self.assertLogs('mkdocs') as cm:
             build._build_theme_template('missing.html', env, mock.Mock(), cfg, mock.Mock())
         self.assertEqual(
-            cm.output,
-            ["WARNING:mkdocs.commands.build:Template skipped: 'missing.html' not found in theme directories."]
+            '\n'.join(cm.output),
+            "WARNING:mkdocs.commands.build:Template skipped: 'missing.html' not found in theme directories.",
         )
         mock_write_file.assert_not_called()
         mock_build_template.assert_not_called()
@@ -223,62 +257,67 @@ class BuildTests(PathAssertionMixin, unittest.TestCase):
     def test_skip_theme_template_empty_output(self, mock_build_template, mock_write_file):
         cfg = load_config()
         env = cfg['theme'].get_env()
-        with self.assertLogs('mkdocs', level='INFO') as cm:
+        with self.assertLogs('mkdocs') as cm:
             build._build_theme_template('main.html', env, mock.Mock(), cfg, mock.Mock())
         self.assertEqual(
-            cm.output,
-            ["INFO:mkdocs.commands.build:Template skipped: 'main.html' generated empty output."]
+            '\n'.join(cm.output),
+            "INFO:mkdocs.commands.build:Template skipped: 'main.html' generated empty output.",
         )
         mock_write_file.assert_not_called()
         mock_build_template.assert_called_once()
 
     # Test build._build_extra_template
 
+    @tempdir()
     @mock.patch('mkdocs.commands.build.open', mock.mock_open(read_data='template content'))
-    def test_build_extra_template(self):
-        cfg = load_config()
-        files = Files([
+    def test_build_extra_template(self, site_dir):
+        cfg = load_config(site_dir=site_dir)
+        fs = [
             File('foo.html', cfg['docs_dir'], cfg['site_dir'], cfg['use_directory_urls']),
-        ])
+        ]
+        files = Files(fs)
         build._build_extra_template('foo.html', files, cfg, mock.Mock())
 
     @mock.patch('mkdocs.commands.build.open', mock.mock_open(read_data='template content'))
     def test_skip_missing_extra_template(self):
         cfg = load_config()
-        files = Files([
+        fs = [
             File('foo.html', cfg['docs_dir'], cfg['site_dir'], cfg['use_directory_urls']),
-        ])
-        with self.assertLogs('mkdocs', level='INFO') as cm:
+        ]
+        files = Files(fs)
+        with self.assertLogs('mkdocs') as cm:
             build._build_extra_template('missing.html', files, cfg, mock.Mock())
         self.assertEqual(
-            cm.output,
-            ["WARNING:mkdocs.commands.build:Template skipped: 'missing.html' not found in docs_dir."]
+            '\n'.join(cm.output),
+            "WARNING:mkdocs.commands.build:Template skipped: 'missing.html' not found in docs_dir.",
         )
 
     @mock.patch('mkdocs.commands.build.open', side_effect=OSError('Error message.'))
     def test_skip_ioerror_extra_template(self, mock_open):
         cfg = load_config()
-        files = Files([
+        fs = [
             File('foo.html', cfg['docs_dir'], cfg['site_dir'], cfg['use_directory_urls']),
-        ])
-        with self.assertLogs('mkdocs', level='INFO') as cm:
+        ]
+        files = Files(fs)
+        with self.assertLogs('mkdocs') as cm:
             build._build_extra_template('foo.html', files, cfg, mock.Mock())
         self.assertEqual(
-            cm.output,
-            ["WARNING:mkdocs.commands.build:Error reading template 'foo.html': Error message."]
+            '\n'.join(cm.output),
+            "WARNING:mkdocs.commands.build:Error reading template 'foo.html': Error message.",
         )
 
     @mock.patch('mkdocs.commands.build.open', mock.mock_open(read_data=''))
     def test_skip_extra_template_empty_output(self):
         cfg = load_config()
-        files = Files([
+        fs = [
             File('foo.html', cfg['docs_dir'], cfg['site_dir'], cfg['use_directory_urls']),
-        ])
-        with self.assertLogs('mkdocs', level='INFO') as cm:
+        ]
+        files = Files(fs)
+        with self.assertLogs('mkdocs') as cm:
             build._build_extra_template('foo.html', files, cfg, mock.Mock())
         self.assertEqual(
-            cm.output,
-            ["INFO:mkdocs.commands.build:Template skipped: 'foo.html' generated empty output."]
+            '\n'.join(cm.output),
+            "INFO:mkdocs.commands.build:Template skipped: 'foo.html' generated empty output.",
         )
 
     # Test build._populate_page
@@ -298,7 +337,9 @@ class BuildTests(PathAssertionMixin, unittest.TestCase):
         page = Page('Foo', file, cfg)
         build._populate_page(page, cfg, Files([file]), dirty=True)
         self.assertTrue(page.markdown.startswith('# Welcome to MkDocs'))
-        self.assertTrue(page.content.startswith('<h1 id="welcome-to-mkdocs">Welcome to MkDocs</h1>'))
+        self.assertTrue(
+            page.content.startswith('<h1 id="welcome-to-mkdocs">Welcome to MkDocs</h1>')
+        )
 
     @tempdir(files={'index.md': 'page content'})
     @tempdir(files={'index.html': '<p>page content</p>'})
@@ -317,30 +358,32 @@ class BuildTests(PathAssertionMixin, unittest.TestCase):
         cfg = load_config(docs_dir=docs_dir)
         file = File('missing.md', cfg['docs_dir'], cfg['site_dir'], cfg['use_directory_urls'])
         page = Page('Foo', file, cfg)
-        with self.assertLogs('mkdocs', level='ERROR') as cm:
+        with self.assertLogs('mkdocs') as cm:
             with self.assertRaises(OSError):
                 build._populate_page(page, cfg, Files([file]))
         self.assertEqual(
-            cm.output, [
+            cm.output,
+            [
                 'ERROR:mkdocs.structure.pages:File not found: missing.md',
-                "ERROR:mkdocs.commands.build:Error reading page 'missing.md': Error message."
-            ]
+                "ERROR:mkdocs.commands.build:Error reading page 'missing.md': Error message.",
+            ],
         )
         mock_open.assert_called_once()
 
     @tempdir(files={'index.md': 'page content'})
-    @mock.patch('mkdocs.plugins.PluginCollection.run_event', side_effect=PluginError('Error message.'))
+    @mock.patch(
+        'mkdocs.plugins.PluginCollection.run_event', side_effect=PluginError('Error message.')
+    )
     def test_populate_page_read_plugin_error(self, docs_dir, mock_open):
         cfg = load_config(docs_dir=docs_dir)
         file = File('index.md', cfg['docs_dir'], cfg['site_dir'], cfg['use_directory_urls'])
         page = Page('Foo', file, cfg)
-        with self.assertLogs('mkdocs', level='ERROR') as cm:
+        with self.assertLogs('mkdocs') as cm:
             with self.assertRaises(PluginError):
                 build._populate_page(page, cfg, Files([file]))
         self.assertEqual(
-            cm.output, [
-                "ERROR:mkdocs.commands.build:Error reading page 'index.md':"
-            ]
+            '\n'.join(cm.output),
+            "ERROR:mkdocs.commands.build:Error reading page 'index.md':",
         )
         mock_open.assert_called_once()
 
@@ -349,7 +392,8 @@ class BuildTests(PathAssertionMixin, unittest.TestCase):
     @tempdir()
     def test_build_page(self, site_dir):
         cfg = load_config(site_dir=site_dir, nav=['index.md'], plugins=[])
-        files = Files([File('index.md', cfg['docs_dir'], cfg['site_dir'], cfg['use_directory_urls'])])
+        fs = [File('index.md', cfg['docs_dir'], cfg['site_dir'], cfg['use_directory_urls'])]
+        files = Files(fs)
         nav = get_navigation(files, cfg)
         page = files.documentation_pages()[0].page
         # Fake populate page
@@ -363,13 +407,16 @@ class BuildTests(PathAssertionMixin, unittest.TestCase):
     @mock.patch('jinja2.environment.Template.render', return_value='')
     def test_build_page_empty(self, site_dir, render_mock):
         cfg = load_config(site_dir=site_dir, nav=['index.md'], plugins=[])
-        files = Files([File('index.md', cfg['docs_dir'], cfg['site_dir'], cfg['use_directory_urls'])])
+        fs = [File('index.md', cfg['docs_dir'], cfg['site_dir'], cfg['use_directory_urls'])]
+        files = Files(fs)
         nav = get_navigation(files, cfg)
-        with self.assertLogs('mkdocs', level='INFO') as cm:
-            build._build_page(files.documentation_pages()[0].page, cfg, files, nav, cfg['theme'].get_env())
+        with self.assertLogs('mkdocs') as cm:
+            build._build_page(
+                files.documentation_pages()[0].page, cfg, files, nav, cfg['theme'].get_env()
+            )
         self.assertEqual(
-            cm.output,
-            ["INFO:mkdocs.commands.build:Page skipped: 'index.md'. Generated empty output."]
+            '\n'.join(cm.output),
+            "INFO:mkdocs.commands.build:Page skipped: 'index.md'. Generated empty output.",
         )
         self.assertPathNotFile(site_dir, 'index.html')
         render_mock.assert_called_once()
@@ -379,34 +426,41 @@ class BuildTests(PathAssertionMixin, unittest.TestCase):
     @mock.patch('mkdocs.utils.write_file')
     def test_build_page_dirty_modified(self, site_dir, docs_dir, mock_write_file):
         cfg = load_config(docs_dir=docs_dir, site_dir=site_dir, nav=['index.md'], plugins=[])
-        files = Files([File('index.md', cfg['docs_dir'], cfg['site_dir'], cfg['use_directory_urls'])])
+        fs = [File('index.md', cfg['docs_dir'], cfg['site_dir'], cfg['use_directory_urls'])]
+        files = Files(fs)
         nav = get_navigation(files, cfg)
         page = files.documentation_pages()[0].page
         # Fake populate page
         page.title = 'Title'
         page.markdown = 'new page content'
         page.content = '<p>new page content</p>'
-        build._build_page(page, cfg, files, nav, self._get_env_with_null_translations(cfg), dirty=True)
+        build._build_page(
+            page, cfg, files, nav, self._get_env_with_null_translations(cfg), dirty=True
+        )
         mock_write_file.assert_not_called()
 
     @tempdir(files={'testing.html': '<p>page content</p>'})
     @mock.patch('mkdocs.utils.write_file')
     def test_build_page_dirty_not_modified(self, site_dir, mock_write_file):
         cfg = load_config(site_dir=site_dir, nav=['testing.md'], plugins=[])
-        files = Files([File('testing.md', cfg['docs_dir'], cfg['site_dir'], cfg['use_directory_urls'])])
+        fs = [File('testing.md', cfg['docs_dir'], cfg['site_dir'], cfg['use_directory_urls'])]
+        files = Files(fs)
         nav = get_navigation(files, cfg)
         page = files.documentation_pages()[0].page
         # Fake populate page
         page.title = 'Title'
         page.markdown = 'page content'
         page.content = '<p>page content</p>'
-        build._build_page(page, cfg, files, nav, self._get_env_with_null_translations(cfg), dirty=True)
+        build._build_page(
+            page, cfg, files, nav, self._get_env_with_null_translations(cfg), dirty=True
+        )
         mock_write_file.assert_called_once()
 
     @tempdir()
     def test_build_page_custom_template(self, site_dir):
         cfg = load_config(site_dir=site_dir, nav=['index.md'], plugins=[])
-        files = Files([File('index.md', cfg['docs_dir'], cfg['site_dir'], cfg['use_directory_urls'])])
+        fs = [File('index.md', cfg['docs_dir'], cfg['site_dir'], cfg['use_directory_urls'])]
+        files = Files(fs)
         nav = get_navigation(files, cfg)
         page = files.documentation_pages()[0].page
         # Fake populate page
@@ -421,58 +475,58 @@ class BuildTests(PathAssertionMixin, unittest.TestCase):
     @mock.patch('mkdocs.utils.write_file', side_effect=OSError('Error message.'))
     def test_build_page_error(self, site_dir, mock_write_file):
         cfg = load_config(site_dir=site_dir, nav=['index.md'], plugins=[])
-        files = Files([File('index.md', cfg['docs_dir'], cfg['site_dir'], cfg['use_directory_urls'])])
+        fs = [File('index.md', cfg['docs_dir'], cfg['site_dir'], cfg['use_directory_urls'])]
+        files = Files(fs)
         nav = get_navigation(files, cfg)
         page = files.documentation_pages()[0].page
         # Fake populate page
         page.title = 'Title'
         page.markdown = 'page content'
         page.content = '<p>page content</p>'
-        with self.assertLogs('mkdocs', level='ERROR') as cm:
+        with self.assertLogs('mkdocs') as cm:
             with self.assertRaises(OSError):
-                build._build_page(
-                    page,
-                    cfg,
-                    files,
-                    nav,
-                    self._get_env_with_null_translations(cfg)
-                )
+                build._build_page(page, cfg, files, nav, self._get_env_with_null_translations(cfg))
         self.assertEqual(
-            cm.output,
-            ["ERROR:mkdocs.commands.build:Error building page 'index.md': Error message."]
+            '\n'.join(cm.output),
+            "ERROR:mkdocs.commands.build:Error building page 'index.md': Error message.",
         )
         mock_write_file.assert_called_once()
 
     @tempdir()
-    @mock.patch('mkdocs.plugins.PluginCollection.run_event', side_effect=PluginError('Error message.'))
+    @mock.patch(
+        'mkdocs.plugins.PluginCollection.run_event', side_effect=PluginError('Error message.')
+    )
     def test_build_page_plugin_error(self, site_dir, mock_write_file):
         cfg = load_config(site_dir=site_dir, nav=['index.md'], plugins=[])
-        files = Files([File('index.md', cfg['docs_dir'], cfg['site_dir'], cfg['use_directory_urls'])])
+        fs = [File('index.md', cfg['docs_dir'], cfg['site_dir'], cfg['use_directory_urls'])]
+        files = Files(fs)
         nav = get_navigation(files, cfg)
         page = files.documentation_pages()[0].page
         # Fake populate page
         page.title = 'Title'
         page.markdown = 'page content'
         page.content = '<p>page content</p>'
-        with self.assertLogs('mkdocs', level='ERROR') as cm:
+        with self.assertLogs('mkdocs') as cm:
             with self.assertRaises(PluginError):
                 build._build_page(page, cfg, files, nav, cfg['theme'].get_env())
         self.assertEqual(
-            cm.output,
-            ["ERROR:mkdocs.commands.build:Error building page 'index.md':"]
+            '\n'.join(cm.output),
+            "ERROR:mkdocs.commands.build:Error building page 'index.md':",
         )
         mock_write_file.assert_called_once()
 
     # Test build.build
 
-    @tempdir(files={
-        'index.md': 'page content',
-        'empty.md': '',
-        'img.jpg': '',
-        'static.html': 'content',
-        '.hidden': 'content',
-        '.git/hidden': 'content'
-    })
+    @tempdir(
+        files={
+            'index.md': 'page content',
+            'empty.md': '',
+            'img.jpg': '',
+            'static.html': 'content',
+            '.hidden': 'content',
+            '.git/hidden': 'content',
+        }
+    )
     @tempdir()
     def test_copying_media(self, site_dir, docs_dir):
         cfg = load_config(docs_dir=docs_dir, site_dir=site_dir)
